#!/bin/sh
# findmerge_cmn.sh -- common findmerge script
#
# $1-n  findmerge command arguments and options (NOT keyword 'findmerge')
#

SFX="`date +%d-%m.%H:%M:%S`"
trap 'rm -f /tmp/findmerge.$SFX; exit 1' 1 2 3 9 15

clearprompt yes_no -type ok -prefer_gui -prompt \
"Mergers can be performed in a highly automated mode or in
a manual mode.  If you select the automatic mode, you will only be
required to resolve conflicting changes.  If you select the manual mode,
you will have to review each change, but you will have complete control
over what is output from the merge process.

Run this merger in automatic mode?"

st=$?
if [ $st = 2 ] ; then
    exit 1
else if [ $st = 0 ] ; then
    MODE=""
else
    MODE="-qall"
fi fi

clearprompt yes_no -type ok -prefer_gui -prompt \
"Actual merge commands can be executed as each file or directory
which requires a merge is found. Alternatively, they can be
executed from a log file script when this command completes.

Execute mergers as they are found?"

st=$?
if [ $st = 2 ] ; then
    exit 1
else if [ $st = 0 ] ; then
    if [ "$MODE" = "-qall" ]; then
	EXEC="-gmerge -qall"
    else
    	EXEC="-merge -gmerge"
    fi
else
    if [ "$MODE" = "-qall" ]; then
	EXEC="-print"
    else
	EXEC="-print -qall"
    fi
fi fi

clearprompt yes_no -type ok -prefer_gui -prompt \
"In addition to a list of required mergers, you can receive an
explanation of why other elements do not require a merger.

Explain why certain elements do NOT need to be merged?"

st=$?
if [ $st = 2 ] ; then
    exit 1
else if [ $st = 0 ] ; then
    WHYNOT="-whynot"
else
    WHYNOT=""
fi fi
	
rm -f /tmp/findmerge.$SFX

#------------- Script run by xterm -------------

cat <<! >/tmp/findmerge.$SFX
trap 'echo "Type <CR> to exit"; read xxx; exit 1' 1 2 3 9 15

# Enable ^C on SGI
if [ "$XC_EXEC_NAME" = "xwsh" ] ; then
    if [ ! -r $HOME/.wshttymodestty ] ; then
	stty intr '^C' 2>/dev/null
    fi
fi

MERGE_LATER=0

cleartool findmerge $* $EXEC $WHYNOT -log findmerge.$SFX.log
chmod +x findmerge.$SFX.log

if [ "$EXEC" = "-print" ] ; then
    # no mergers done yet, tell user about log file
    if [ -f findmerge.$SFX.log ] ; then
	# There is a log file
	MRG_CNT=\`grep "^cleartool" findmerge.$SFX.log | wc -l | sed -e 's/ *//'\`
    	if [ "\$MRG_CNT" = 0 ]; then
	    # remove empty log file
	    rm -f findmerge.$SFX.log
	    MSG="No merges are needed"
	    MERGE_LATER=0
	else
	    # tell user about log file
	    if [ \$MRG_CNT = 1 ] ; then
		MSG="A log file has been written indicating 1 merger needs to be performed."
	    else
		MSG="A log file has been written indicating \$MRG_CNT mergers need to be performed."
	    fi
	    MERGE_LATER=1 # ask user to run these merges later
	fi
    else
	# no log because nothing needs merging
	MSG="No merges are needed"
	MERGE_LATER=0
    fi
else
    # already did merges, if any
    MERGE_LATER=0
    if [ -f findmerge.$SFX.log ] ; then
    	MSG="See findmerge.$SFX.log for a summary of merge results."
    else
	MSG=""     # nothing needed merging
    fi
fi

if [ -f findmerge.$SFX.log ] ; then
    # There are some required/completed mergers
    echo
    echo Wrote log file \\"findmerge.$SFX.log\\"
fi

#
# Tell user about final status in a clearprompt box
#
if [ "\$MSG" != "" ] ; then
    if [ \$MERGE_LATER = 0 ] ; then
	clearprompt proceed -mask proceed -type ok -prefer_gui -prompt "\$MSG"
    else
# massage merge list
	if [ "$MODE" = "-qall" ]; then
		sed -e 's/-merge/-gmerge -qall/g' < findmerge.$SFX.log \
			>  findmerge.$SFX.log$$
		mv -f findmerge.$SFX.log$$ findmerge.$SFX.log
		chmod a+x findmerge.$SFX.log
	fi
	MSG="\$MSG
The script with merge commands is: findmerge.$SFX.log

    Run the merge script now?"
	if clearprompt yes_no -mask yes,no -type ok -prefer_gui -prompt "\$MSG" ; then
	    echo "---- running findmerge.$SFX.log ..."
	    findmerge.$SFX.log
	fi
    fi
fi

# If no log (=> no merges needed) and not -whynot (no explanation)
# then no reason to keep shell around.
#
if [ ! -f findmerge.$SFX.log ] ; then
    if [ "$WHYNOT" != "-whynot" ] ; then
	exit 0
    fi
fi

echo "Type <CR> to exit"
read xxx
!

#-----------------------------------------------

chmod +x /tmp/findmerge.$SFX
if [ "$XC_SCROLLBAR_FLAG" != "" ] ; then
    MORE_XC_ARGS="$XC_SCROLLBAR_FLAG"
    if [ "$XC_SCROLLBAR_ARG" != "" ] ; then
        MORE_XC_ARGS="$MORE_XC_ARGS $XC_SCROLLBAR_ARG"
    fi
fi
if [ "$XC_SAVE_LINES_FLAG" != "" ] ; then
    MORE_XC_ARGS="$MORE_XC_ARGS $XC_SAVE_LINES_FLAG 500"
fi

#
# Japanese terminal support
#
if [ "$LANG" != "" -a "$XC_EXEC_NAME" = "xterm" ]; then
	LANG_PREFIX=`echo $LANG | cut -c 1,2 | tr '[A-Z]' '[a-z]'`
	if [ "$LANG_PREFIX" = "ja" -o "$LANG_PREFIX" = "jp" ]; then
	    # find kanji terminal command
	    kanji_term_cmd=`type gnome-terminal 2> /dev/null | awk '{ print $NF }'`
	    if [ "$kanji_term_cmd" != "" ]; then
	       TERM_FLAG="--disable-factory"
	    else
		kanji_term_cmd=`type aterm 2> /dev/null | awk '{ print $NF }'`	       
		if [ "$kanji_term_cmd" = "" ]; then
		    kanji_term_cmd=`type kterm 2> /dev/null | awk '{ print $NF }'`
		    LANG_SUFFIX=`echo $LANG | cut -c 7,8,9,10| tr '[A-Z]' '[a-z]'`
		    ORIG_LANG_PREFIX=`echo $LANG | cut -c 1,2`
		    if [ "$LANG_SUFFIX" = "sjis" -o "$ORIG_LANG_PREFIX" = "Ja" ]; then
			TERM_FLAG="-km sjis"
		    else
			TERM_FLAG="-km euc"
		    fi
		fi
	    fi
	    if [ "$kanji_term_cmd" != "" ]; then
		XC_EXEC_PNAME=$kanji_term_cmd; export XC_EXEC_PNAME
	    else
		TERM_FLAG=""
	    fi
	fi
fi

($XC_EXEC_PNAME $TERM_FLAG $MORE_XC_ARGS $XC_COMMAND_FLAG /tmp/findmerge.$SFX ; rm -f /tmp/findmerge.$SFX) &
